from fastapi import APIRouter, HTTPException, status
from schemas.contactform import ContactFormCreate
from helpers.contactform_helpers import create_contact_form, validate_contact_form_data
from sqlalchemy.orm import Session
from fastapi import Depends
from core.database import get_db

router = APIRouter()

@router.post("/contact-us", status_code=status.HTTP_201_CREATED, response_model=ContactFormCreate)
async def create_contact_form_submission(
    contact_form_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    if not validate_contact_form_data(contact_form_data):
        raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail="All fields are required")
    
    new_contact_form = create_contact_form(db=db, contact_form_data=contact_form_data)
    return new_contact_form